-- if the table exists, drop it so we can reload it
DROP TEMPORARY TABLE IF EXISTS s70;

-- create the table with the following fields
CREATE TEMPORARY TABLE s70 (
	filename VARCHAR(32),
	data_loc VARCHAR(100),
 	file_size_bytes INT(32),
	project_id VARCHAR(10),
	hdrver VARCHAR(10),
	survey VARCHAR(10),
	telescope VARCHAR(16),
 	site VARCHAR(8),    
	src_name VARCHAR(16),
 	date VARCHAR(16),   
 	ut VARCHAR(16),   
 	MJD DECIMAL(32,26),
	raj VARCHAR(20),
	decj VARCHAR(20),
	rajd DOUBLE,
	decjd DOUBLE,
	gl DOUBLE,
	gb DOUBLE,
	bmaj FLOAT,
	bmin FLOAT,
	bpa FLOAT,
	dm DECIMAL(16,10),
	period DECIMAL(32,24),
	cnfg VARCHAR(128),
 	inst VARCHAR(32),
	data_type VARCHAR(128),
 	rcvr VARCHAR(16),   
 	obsrvr VARCHAR(32),   
        obsfreq DECIMAL(32,16),
	chanbw DECIMAL(16,6),
 	nchan INT(6),        
	npol INT(6),
 	nbin INT(6),        
 	nsub INT(6),        
 	scanlen DECIMAL(32,20),
 	tsamp FLOAT,       
	nbits tinyint(3) unsigned,  
	nbeam tinyint(3) unsigned,
	PRIMARY KEY (filename, data_loc)
);

LOAD DATA LOCAL
INFILE "/pulsar/archive13/S70V/summary_S70.csv"
INTO TABLE s70
FIELDS TERMINATED BY ","
OPTIONALLY ENCLOSED BY "\""
IGNORE 1 LINES  -- this ignores the first line in the csv file which contains the column headers.
(filename,data_loc,file_size_bytes,project_id,hdrver,survey,telescope,site,src_name,date,ut,MJD,raj,decj,rajd,decjd,gl,gb,bmaj,bmin,bpa,dm,period,cnfg,inst,data_type,rcvr,obsrvr,obsfreq,chanbw,nchan,npol,nbin,nsub,scanlen,tsamp,nbits,nbeam);


-- base coords for galactic coord transformation.
SET @ngpra=192.859508, @ngpdec=27.128336, @ascnode=32.932; 

-- if the table exists, drop it so we can reload it
DROP TEMPORARY TABLE IF EXISTS obs;

-- create the table with the following fields
CREATE TEMPORARY TABLE obs (
	filename VARCHAR(32),
	data_loc VARCHAR(100),
 	file_size_bytes INT(32),
	project_id VARCHAR(10),
	hdrver VARCHAR(10),
	survey VARCHAR(10),
	telescope VARCHAR(16),
 	site VARCHAR(8),    
	src_name VARCHAR(16),
 	date VARCHAR(16),   
 	ut VARCHAR(16),   
 	MJD DECIMAL(32,26),
	raj VARCHAR(20),
	decj VARCHAR(20),
	rajd DOUBLE,
	decjd DOUBLE,
	gl DOUBLE,
	gb DOUBLE,
	bmaj FLOAT,
	bmin FLOAT,
	bpa FLOAT,
	dm DECIMAL(16,10),
	period DECIMAL(32,24),
	cnfg VARCHAR(128),
 	inst VARCHAR(32),
	data_type VARCHAR(128),
 	rcvr VARCHAR(16),   
 	obsrvr VARCHAR(32),   
        obsfreq DECIMAL(32,16),
	chanbw DECIMAL(16,6),
 	nchan INT(6),        
	npol INT(6),
 	nbin INT(6),        
 	nsub INT(6),        
 	scanlen DECIMAL(32,20),
 	tsamp FLOAT,       
	nbits tinyint(3) unsigned,  
	nbeam tinyint(3) unsigned,
	PRIMARY KEY (filename, data_loc)
)
 SELECT
	o.filename, 
	o.data_loc, 
	o.file_size_bytes, 
	NULL as project_id,
	NULL as hdrver,
	NULL as survey,
	'PARKES' as telescope,
	o.site as site,
	o.pulsar_name as src_name,
	o.date as date,
	o.ut as ut,
	o.MJD as MJD,
	concat(raj_hour,':',raj_minute,':',raj_second) as raj,
	case 
	     when (o.pulsar_name like '%-%') 
		then concat('-',abs(o.decj_degree),':',o.decj_minute,':',o.decj_second)
	     when (o.decj_degree<0.) 
		then concat('-',abs(o.decj_degree),':',o.decj_minute,':',o.decj_second)
             else concat(abs(o.decj_degree),':',o.decj_minute,':',o.decj_second) 
    	end as decj,
        (o.raj_hour+o.raj_minute/60.+o.raj_second/3600.)*15. as rajd,
        case when o.pulsar_name like "%-%" 
		then -1.*(abs(o.decj_degree)+o.decj_minute/60.+o.decj_second/3600.)
             when (o.decj_degree<0.)
		then -1.*(abs(o.decj_degree)+o.decj_minute/60.+o.decj_second/3600.)
             else abs(o.decj_degree)+o.decj_minute/60.+o.decj_second/3600. 
	end as decjd,
	NULL as gl, 
	NULL as gb,
	(1.2*(299792458./(o.freq*1.e6))/64.) * 180./pi() as BMAJ,
	(1.2*(299792458./(o.freq*1.e6))/64.) * 180./pi() as BMIN,
	0. as BPA,
	o.dm, 
	o.period, 
	o.cnfg,
	o.inst,
	o.data_type,
	o.rcvr,
	o.obsrvr,
	o.freq as obsfreq,
	o.bw as chanbw,
	o.nchan,
	o.npol,
	o.nbin, 
	o.nsub, 
	o.length as scanlen, 
	o.tsamp,
	NULL as nbits,
	o.nbeam	
 FROM observations as o;


UPDATE obs
  SET	gl = case 
		when degrees( atan2( ( sin(radians(decjd))*cos(radians(@ngpdec)) - cos(radians(decjd))*sin(radians(@ngpdec))*cos(radians(rajd-@ngpra)) ) , ( cos(radians(decjd))*sin(radians(rajd-@ngpra)) ) ) ) + @ascnode > 0 
	        then degrees( atan2( ( sin(radians(decjd))*cos(radians(@ngpdec)) - cos(radians(decjd))*sin(radians(@ngpdec))*cos(radians(rajd-@ngpra)) ) , ( cos(radians(decjd))*sin(radians(rajd-@ngpra)) ) ) ) + @ascnode
       		else degrees( atan2( ( sin(radians(decjd))*cos(radians(@ngpdec)) - cos(radians(decjd))*sin(radians(@ngpdec))*cos(radians(rajd-@ngpra)) ) , ( cos(radians(decjd))*sin(radians(rajd-@ngpra)) ) ) ) + @ascnode + 360.
	   end,
	gb = (degrees( asin( cos(radians(decjd))*cos(radians(@ngpdec))*cos(radians(rajd-@ngpra)) + sin(radians(decjd))*sin(radians(@ngpdec)))));

--------------------------------------
-- Now create the new cals table
--
-- if the table exists, drop it so we can reload it
DROP TEMPORARY TABLE IF EXISTS calib;

-- create the table with the following fields
CREATE TEMPORARY TABLE calib (
	filename VARCHAR(32),
	data_loc VARCHAR(100),
 	file_size_bytes INT(32),
	project_id VARCHAR(10),
	hdrver VARCHAR(10),
	survey VARCHAR(10),
	telescope VARCHAR(16),
 	site VARCHAR(8),    
	src_name VARCHAR(16),
 	date VARCHAR(16),   
 	ut VARCHAR(16),   
 	MJD DECIMAL(32,26),
	raj VARCHAR(20),
	decj VARCHAR(20),
	rajd DOUBLE,
	decjd DOUBLE,
	gl DOUBLE,
	gb DOUBLE,
	bmaj FLOAT,
	bmin FLOAT,
	bpa FLOAT,
	dm DECIMAL(16,10),
	period DECIMAL(32,24),
	cnfg VARCHAR(128),
 	inst VARCHAR(32),
	data_type VARCHAR(128),
 	rcvr VARCHAR(16),   
 	obsrvr VARCHAR(32),   
        obsfreq DECIMAL(32,16),
	chanbw DECIMAL(16,6),
 	nchan INT(6),        
	npol INT(6),
 	nbin INT(6),        
 	nsub INT(6),        
 	scanlen DECIMAL(32,20),
 	tsamp FLOAT,       
	nbits tinyint(3) unsigned,  
	nbeam tinyint(3) unsigned,
	PRIMARY KEY (filename, data_loc)
)
 SELECT
	c.filename, 
	c.data_loc, 
	c.file_size_bytes, 
	NULL as project_id,
	NULL as hdrver,
	NULL as survey,
	'PARKES' as telescope,
	c.site as site,
	c.pulsar_name as src_name,
	NULL as date,
	NULL as ut,
	c.MJD as MJD,
	concat(raj_hour,':',raj_minute,':',raj_second) as raj,
	case 
	     when (c.pulsar_name like '%-%') 
		then concat('-',abs(c.decj_degree),':',c.decj_minute,':',c.decj_second)
	     when (c.decj_degree<0.) 
		then concat('-',abs(c.decj_degree),':',c.decj_minute,':',c.decj_second)
             else concat(abs(c.decj_degree),':',c.decj_minute,':',c.decj_second) 
    	end as decj,
        (c.raj_hour+c.raj_minute/60.+c.raj_second/3600.)*15. as rajd,
        case when c.pulsar_name like "%-%" 
		then -1.*(abs(c.decj_degree)+c.decj_minute/60.+c.decj_second/3600.)
             when (c.decj_degree<0.)
		then -1.*(abs(c.decj_degree)+c.decj_minute/60.+c.decj_second/3600.)
             else abs(c.decj_degree)+c.decj_minute/60.+c.decj_second/3600. 
	end as decjd,
	NULL as gl, 
	NULL as gb,
	(1.2*(299792458./(c.freq*1.e6))/64.) * 180./pi() as BMAJ,
	(1.2*(299792458./(c.freq*1.e6))/64.) * 180./pi() as BMIN,
	0. as BPA,
	c.dm, 
	c.period, 
	c.cnfg,
	c.inst,
	c.data_type,
	c.rcvr,
	c.obsrvr,
	c.freq as obsfreq,
	c.bw as chanbw,
	c.nchan,
	c.npol,
	c.nbin, 
	c.nsub, 
	NULL as scanlen, 
	NULL as tsamp,
	NULL as nbits,
	NULL as nbeam	
 FROM cals as c;

UPDATE calib
  SET	gl = case 
		when degrees( atan2( ( sin(radians(decjd))*cos(radians(@ngpdec)) - cos(radians(decjd))*sin(radians(@ngpdec))*cos(radians(rajd-@ngpra)) ) , ( cos(radians(decjd))*sin(radians(rajd-@ngpra)) ) ) ) + @ascnode > 0 
	        then degrees( atan2( ( sin(radians(decjd))*cos(radians(@ngpdec)) - cos(radians(decjd))*sin(radians(@ngpdec))*cos(radians(rajd-@ngpra)) ) , ( cos(radians(decjd))*sin(radians(rajd-@ngpra)) ) ) ) + @ascnode
       		else degrees( atan2( ( sin(radians(decjd))*cos(radians(@ngpdec)) - cos(radians(decjd))*sin(radians(@ngpdec))*cos(radians(rajd-@ngpra)) ) , ( cos(radians(decjd))*sin(radians(rajd-@ngpra)) ) ) ) + @ascnode + 360.
	   end,
	gb = (degrees( asin( cos(radians(decjd))*cos(radians(@ngpdec))*cos(radians(rajd-@ngpra)) + sin(radians(decjd))*sin(radians(@ngpdec)))));